.. picast documentation master file, created by
   sphinx-quickstart on Mon Aug 19 07:46:24 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to picast's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   design
   settings
   authors
   changes



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
